TestYubikiriProvider<T extends Yubikiri> class

A Provider class that is able to inject a mocked Yubikiri into a View

To use this, you just have to wrap this class around the View you want to test and a dd a viewModel. From this point on, the View will only reference the Mock.

late MyViewModel _myViewModel

Future<void> pumpWidget(WidgetTester tester) {
  _myViewModel = MockMyViewModel();

  await tester.pumpApp(
    TestViewModelProvider<MyViewModel>(
      viewModel: _myViewModel,
      child: MyView(),
    )
  )
}
Inheritance

Constructors

TestYubikiriProvider({Key? key, required Widget child, required T yubikiri})
const

Properties

child Widget
The widget below this widget in the tree.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
yubikiri → T
final

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant TestYubikiriProvider<Yubikiri> oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exists<T extends Yubikiri>(BuildContext context) bool
maybeOf<T extends Yubikiri>(BuildContext context) TestYubikiriProvider<T>?